type range = Int32.t * Int32.t
type textdomain = string
type locale = string
type dir = string
type filename = string
type codeset = string
exception CompileProblemReadingFile of filename * string
exception CompileExtractionFailed of filename * string * int
exception CompileExtractionInterrupted of filename * string * int
exception DomainFileDoesntExist of filename list
exception FormatInconsistent of string * string
exception GettextUninitialized
exception MoInvalidOptions of Lexing.lexbuf * string
exception MoInvalidPlurals of Lexing.lexbuf * string
exception MoInvalidContentType of Lexing.lexbuf * string
exception MoInvalidTranslationSingular of string * int
exception MoInvalidTranslationPlural of string list * int
exception MoJunk of string * string list
exception MoEmptyEntry
exception MoInvalidFile
exception MoInvalidHeaderNegativeStrings
exception MoInvalidHeaderTableStringOutOfBound of range * range
exception MoInvalidHeaderTableTranslationOutOfBound of range * range
exception MoInvalidHeaderTableTranslationStringOverlap of range * range
exception MoInvalidStringOutOfBound of int * int
exception MoInvalidTranslationOutOfBound of int * int
exception MoCannotOpenFile of string
exception PoInvalidFile of string * Lexing.lexbuf * in_channel
exception PoFileInvalidIndex of string * int
exception PoFileDoesntExist of string
exception PoInconsistentMerge of string * string
exception TranslateStringNotFound of string
exception LocalePosixUnparseable of string
type dependencies = (textdomain * codeset option * dir option) list
module type INIT_TYPE =
  sig
    val textdomain : textdomain
    val codeset : codeset option
    val dir : dir option
    val dependencies : dependencies
  end
module MapString :
  sig
    type key = string
    type +'a t
    val empty : 'a t
    val is_empty : 'a t -> bool
    val add : key -> 'a -> 'a t -> 'a t
    val find : key -> 'a t -> 'a
    val remove : key -> 'a t -> 'a t
    val mem : key -> 'a t -> bool
    val iter : (key -> 'a -> unit) -> 'a t -> unit
    val map : ('a -> 'b) -> 'a t -> 'b t
    val mapi : (key -> 'a -> 'b) -> 'a t -> 'b t
    val fold : (key -> 'a -> 'b -> 'b) -> 'a t -> 'b -> 'b
    val compare : ('a -> 'a -> int) -> 'a t -> 'a t -> int
    val equal : ('a -> 'a -> bool) -> 'a t -> 'a t -> bool
  end
module MapTextdomain :
  sig
    type key = textdomain
    type +'a t
    val empty : 'a t
    val is_empty : 'a t -> bool
    val add : key -> 'a -> 'a t -> 'a t
    val find : key -> 'a t -> 'a
    val remove : key -> 'a t -> 'a t
    val mem : key -> 'a t -> bool
    val iter : (key -> 'a -> unit) -> 'a t -> unit
    val map : ('a -> 'b) -> 'a t -> 'b t
    val mapi : (key -> 'a -> 'b) -> 'a t -> 'b t
    val fold : (key -> 'a -> 'b -> 'b) -> 'a t -> 'b -> 'b
    val compare : ('a -> 'a -> int) -> 'a t -> 'a t -> int
    val equal : ('a -> 'a -> bool) -> 'a t -> 'a t -> bool
  end
type failsafe = Ignore | InformStderr of (exn -> string) | RaiseException
type t = {
  failsafe : failsafe;
  textdomains : (codeset option * dir option) MapTextdomain.t;
  categories : locale GettextCategory.MapCategory.t;
  language : locale option;
  codeset : codeset;
  path : dir list;
  default : textdomain;
}
type t' =
    bool ->
    textdomain option ->
    string -> (string * int) option -> GettextCategory.category -> string
type endianess = BigEndian | LittleEndian
type mo_header = {
  endianess : endianess;
  file_format_revision : int32;
  number_of_strings : int32;
  offset_table_strings : int32;
  offset_table_translation : int32;
  size_of_hashing_table : int32;
  offset_of_hashing_table : int32;
}
type mo_translation = {
  project_id_version : string option;
  report_msgid_bugs_to : string option;
  pot_creation_date : string option;
  po_revision_date : string option;
  last_translator : string option;
  language_tream : string option;
  mime_version : string option;
  content_type : string option;
  content_transfer_encoding : string option;
  plural_forms : string option;
  content_type_charset : string;
  nplurals : int;
  fun_plural_forms : int -> int;
}
type translation =
    Singular of string * string
  | Plural of string * string * string list
type po_translation =
    PoSingular of string list * string list
  | PoPlural of string list * string list * string list list
type po_filepos = filename * int
type po_special = string
type po_commented_translation = {
  po_comment_special : po_special list;
  po_comment_filepos : po_filepos list;
  po_comment_translation : po_translation;
}
type po_translations = po_commented_translation MapString.t
type po_content = {
  no_domain : po_translations;
  domain : po_translations MapTextdomain.t;
}
module type REALIZE_TYPE = sig val realize : t -> t' end
